@@ -6,8 +6,8 @@ import os
 import sys
 import warnings
 
-from keras.callbacks import ModelCheckpoint, EarlyStopping
-from keras.layers import Activation, Layer, LeakyReLU, PReLU, ThresholdedReLU
+from tensorflow.keras.callbacks import ModelCheckpoint, EarlyStopping
+from tensorflow.keras.layers import Activation, Layer, LeakyReLU, PReLU, ThresholdedReLU
 
 import six
 
@@ -344,7 +344,11 @@ class NNBase(ArchBase):
 
     @property
     def model(self):
-        return self._model
+        if hasattr(self, '_model'):
+            return self._model
+        else:
+            name = self.__class__.__name__
+            raise AttributeError("'{}' object has no underlying model".format(name))
 
 
 ###############################################################################
