@@ -1,4 +1,6 @@
-"""Implementation of EFP/EFM Generator class."""
+"""# Multigraph Generation
+
+Implementation of EFP/EFM Generator class."""
 from __future__ import absolute_import, division, print_function
 
 from collections import Counter
@@ -560,5 +562,5 @@ class CompositeGenerator(object):
         mask = [not(form in disc_form_set or disc_form_set.add(form)) for form in disc_formulae]
 
         # store as numpy arrays
-        self.disc_formulae = np.asarray(disc_formulae)[mask]
+        self.disc_formulae = np.asarray(disc_formulae, dtype='O')[mask]
         self.disc_specs = np.asarray(disc_specs)[mask]
\ No newline at end of file
